@@ -25,8 +25,16 @@ def main(args, parser, extra, subparser):
     cli.settings.update_params(args.config_params)
 
     # And do the install
-    cli.install(args.install_recipe, force=args.force)
+    cli.install(
+        args.install_recipe,
+        force=args.force,
+        container_image=args.container_image,
+        keep_path=args.keep_path,
+    )
     if cli.settings.default_view and not args.no_view:
         cli.view_install(
-            cli.settings.default_view, args.install_recipe, force=args.force
+            cli.settings.default_view,
+            args.install_recipe,
+            force=args.force,
+            container_image=args.container_image,
         )
