@@ -12,6 +12,7 @@ import shutil
 
 import pytest
 
+import shpc.main.registry as registry
 import shpc.utils
 
 from .helpers import here, init_client
@@ -70,24 +71,37 @@ def test_features(tmp_path, module_sys, module_file, remote):
     """
     client = init_client(str(tmp_path), module_sys, "singularity", remote=remote)
 
+    module_file_392 = os.path.join(
+        client.settings.module_base, "python", "3.9.2-alpine", module_file
+    )
+    module_file_394 = os.path.join(
+        client.settings.module_base, "python", "3.9.4-alpine", module_file
+    )
+
     # Install known tag
     client.install("python:3.9.2-alpine")
 
-    module_dir = os.path.join(client.settings.module_base, "python", "3.9.2-alpine")
-    module_file = os.path.join(module_dir, module_file)
-
     # Should not have nvidia flag
-    content = shpc.utils.read_file(module_file)
+    content = shpc.utils.read_file(module_file_392)
     assert "--nv" not in content
 
+    client.install("python:3.9.4-alpine")
+    assert os.path.exists(module_file_392)
+    assert os.path.exists(module_file_394)
+
     client.uninstall("python:3.9.2-alpine", force=True)
+    assert not os.path.exists(module_file_392)
+    assert os.path.exists(module_file_394)
+
+    client.uninstall("python", force=True)
+    assert not os.path.exists(module_file_394)
 
     # Now update settings
     client.settings.set("container_features", "gpu:nvidia")
 
     # Install known tag, add extra feature of gpu
     client.install("python:3.9.2-alpine", features=["gpu"])
-    content = shpc.utils.read_file(module_file)
+    content = shpc.utils.read_file(module_file_392)
     assert "--nv" in content
 
 
@@ -364,3 +378,30 @@ def test_add(tmp_path, module_sys, remote):
         client.get("dinosaur/salad:latest")
     client.install("dinosaur/salad:latest")
     assert client.get("dinosaur/salad:latest")
+
+
+def test_remove(tmp_path):
+    """
+    Test removing a container recipe
+    """
+    client = init_client(str(tmp_path), "lmod", "singularity")
+
+    # Create temporary registry that will be empty
+    registry_path = os.path.join(tmp_path, "registry")
+    client.settings.registry = [registry_path]
+    os.makedirs(registry_path)
+    client.reload_registry()
+    assert client.settings.filesystem_registry == registry_path
+
+    # Wrap local test filesystem registry and add module to it
+    test_registry_path = os.path.join(here, "testdata", "registry")
+    test_registry = registry.Filesystem(test_registry_path)
+    module = "dinosaur/salad"
+
+    client.registry.sync_from_remote(test_registry, module)
+
+    # It should exist in the registry
+    assert client.registry.exists(module) is not None
+    # Remove the module (with force)
+    client.remove(module, force=True)
+    assert client.registry.exists(module) is None
